{% comment %}
Slight pollution. This template is picked up by jmbo-foundry. It should really
be moved there.
{% endcomment %}
<div class="title">
    <a href="{{ object.get_absolute_url_categorized }}" title="{{ object.title|escape }}">{{ object.title }}</a>
</div>
